import { appearStoreId } from './store-id.mjs';
import { animateStyle } from '../waapi/index.mjs';
import { optimizedAppearDataId } from './data-id.mjs';
import { handoffOptimizedAppearAnimation } from './handoff.mjs';
import { appearAnimationStore } from './store.mjs';

function startOptimizedAppearAnimation(element, name, keyframes, options, onReady) {
    const id = element.dataset[optimizedAppearDataId];
    if (!id)
        return;
    window.HandoffAppearAnimations = handoffOptimizedAppearAnimation;
    const storeId = appearStoreId(id, name);
    /**
     * Use a dummy animation to detect when Chrome is ready to start
     * painting the page and hold off from triggering the real animation
     * until then.
     */
    const readyAnimation = animateStyle(element, name, [keyframes[0], keyframes[0]], { duration: 1 });
    appearAnimationStore.set(storeId, {
        animation: readyAnimation,
        ready: false,
    });
    const startAnimation = () => {
        const animation = animateStyle(element, name, keyframes, options);
        appearAnimationStore.set(storeId, { animation, ready: true });
        if (onReady)
            onReady(animation);
    };
    if (readyAnimation.ready) {
        readyAnimation.ready.then(() => {
            readyAnimation.cancel();
            startAnimation();
        });
    }
    else {
        startAnimation();
    }
}

export { startOptimizedAppearAnimation };
